@@ -7,13 +7,13 @@ from __future__ import annotations
 
 import os
 import re
-
-from typing import Iterable, Optional, TYPE_CHECKING
+from collections.abc import Iterable
+from typing import TYPE_CHECKING
 
 from coverage.files import flat_rootname
 from coverage.misc import ensure_dir, isolate_module
 from coverage.plugin import FileReporter
-from coverage.report import get_analysis_to_report
+from coverage.report_core import get_analysis_to_report
 from coverage.results import Analysis
 from coverage.types import TMorf
 
@@ -48,12 +48,12 @@ class AnnotateReporter:
     def __init__(self, coverage: Coverage) -> None:
         self.coverage = coverage
         self.config = self.coverage.config
-        self.directory: Optional[str] = None
+        self.directory: str | None = None
 
     blank_re = re.compile(r"\s*(#|$)")
     else_re = re.compile(r"\s*else\s*:\s*(#|$)")
 
-    def report(self, morfs: Optional[Iterable[TMorf]], directory: Optional[str] = None) -> None:
+    def report(self, morfs: Iterable[TMorf] | None, directory: str | None = None) -> None:
         """Run the report.
 
         See `coverage.report()` for arguments.
@@ -77,11 +77,11 @@ class AnnotateReporter:
         if self.directory:
             ensure_dir(self.directory)
             dest_file = os.path.join(self.directory, flat_rootname(fr.relative_filename()))
-            if dest_file.endswith("_py"):
-                dest_file = dest_file[:-3] + ".py"
-            dest_file += ",cover"
+            assert dest_file.endswith("_py")
+            dest_file = dest_file[:-3] + ".py"
         else:
-            dest_file = fr.filename + ",cover"
+            dest_file = fr.filename
+        dest_file += ",cover"
 
         with open(dest_file, "w", encoding="utf-8") as dest:
             i = j = 0
