@@ -8,33 +8,28 @@ from __future__ import annotations
 import contextlib
 import datetime
 import errno
+import functools
 import hashlib
 import importlib
 import importlib.util
 import inspect
-import locale
 import os
 import os.path
 import re
 import sys
 import types
-
+from collections.abc import Iterable, Iterator, Mapping, Sequence
 from types import ModuleType
-from typing import (
-    Any, Callable, Dict, IO, Iterable, Iterator, List, Mapping, Optional,
-    Sequence, Tuple, TypeVar, Union,
-)
-
-from coverage import env
-from coverage.exceptions import CoverageException
-from coverage.types import TArc
+from typing import Any, NoReturn, TypeVar
 
 # In 6.0, the exceptions moved from misc.py to exceptions.py.  But a number of
 # other packages were importing the exceptions from misc, so import them here.
 # pylint: disable=unused-wildcard-import
-from coverage.exceptions import *   # pylint: disable=wildcard-import
+from coverage.exceptions import *  # pylint: disable=wildcard-import
+from coverage.exceptions import CoverageException
+from coverage.types import TArc
 
-ISOLATED_MODULES: Dict[ModuleType, ModuleType] = {}
+ISOLATED_MODULES: dict[ModuleType, ModuleType] = {}
 
 
 def isolate_module(mod: ModuleType) -> ModuleType:
@@ -55,11 +50,13 @@ def isolate_module(mod: ModuleType) -> ModuleType:
             setattr(new_mod, name, value)
     return ISOLATED_MODULES[mod]
 
+
 os = isolate_module(os)
 
 
 class SysModuleSaver:
     """Saves the contents of sys.modules, and removes new modules later."""
+
     def __init__(self) -> None:
         self.old_modules = set(sys.modules)
 
@@ -80,7 +77,7 @@ def sys_modules_saved() -> Iterator[None]:
         saver.restore()
 
 
-def import_third_party(modname: str) -> Tuple[ModuleType, bool]:
+def import_third_party(modname: str) -> tuple[ModuleType, bool]:
     """Import a third-party module we need, but might not be installed.
 
     This also cleans out the module after the import, so that coverage won't
@@ -112,35 +109,12 @@ def nice_pair(pair: TArc) -> str:
     """
     start, end = pair
     if start == end:
-        return "%d" % start
+        return f"{start}"
     else:
-        return "%d-%d" % (start, end)
+        return f"{start}-{end}"
 
 
-TSelf = TypeVar("TSelf")
-TRetVal = TypeVar("TRetVal")
-
-def expensive(fn: Callable[[TSelf], TRetVal]) -> Callable[[TSelf], TRetVal]:
-    """A decorator to indicate that a method shouldn't be called more than once.
-
-    Normally, this does nothing.  During testing, this raises an exception if
-    called more than once.
-
-    """
-    if env.TESTING:
-        attr = "_once_" + fn.__name__
-
-        def _wrapper(self: TSelf) -> TRetVal:
-            if hasattr(self, attr):
-                raise AssertionError(f"Shouldn't have called {fn.__name__} more than once")
-            setattr(self, attr, True)
-            return fn(self)
-        return _wrapper
-    else:
-        return fn                   # pragma: not testing
-
-
-def bool_or_none(b: Any) -> Optional[bool]:
+def bool_or_none(b: Any) -> bool | None:
     """Return bool(b), but preserve None."""
     if b is None:
         return None
@@ -180,51 +154,41 @@ def ensure_dir_for_file(path: str) -> None:
     ensure_dir(os.path.dirname(path))
 
 
-def output_encoding(outfile: Optional[IO[str]] = None) -> str:
-    """Determine the encoding to use for output written to `outfile` or stdout."""
-    if outfile is None:
-        outfile = sys.stdout
-    encoding = (
-        getattr(outfile, "encoding", None) or
-        getattr(sys.__stdout__, "encoding", None) or
-        locale.getpreferredencoding()
-    )
-    return encoding
-
-
 class Hasher:
     """Hashes Python data for fingerprinting."""
+
     def __init__(self) -> None:
-        self.hash = hashlib.new("sha3_256")
+        self.hash = hashlib.new("sha3_256", usedforsecurity=False)
 
     def update(self, v: Any) -> None:
         """Add `v` to the hash, recursively if needed."""
         self.hash.update(str(type(v)).encode("utf-8"))
-        if isinstance(v, str):
-            self.hash.update(v.encode("utf-8"))
-        elif isinstance(v, bytes):
-            self.hash.update(v)
-        elif v is None:
-            pass
-        elif isinstance(v, (int, float)):
-            self.hash.update(str(v).encode("utf-8"))
-        elif isinstance(v, (tuple, list)):
-            for e in v:
-                self.update(e)
-        elif isinstance(v, dict):
-            keys = v.keys()
-            for k in sorted(keys):
-                self.update(k)
-                self.update(v[k])
-        else:
-            for k in dir(v):
-                if k.startswith("__"):
-                    continue
-                a = getattr(v, k)
-                if inspect.isroutine(a):
-                    continue
-                self.update(k)
-                self.update(a)
+        match v:
+            case None:
+                pass
+            case str():
+                self.hash.update(v.encode("utf-8"))
+            case bytes():
+                self.hash.update(v)
+            case int() | float():
+                self.hash.update(str(v).encode("utf-8"))
+            case tuple() | list():
+                for e in v:
+                    self.update(e)
+            case dict():
+                keys = v.keys()
+                for k in sorted(keys):
+                    self.update(k)
+                    self.update(v[k])
+            case _:
+                for k in dir(v):
+                    if k.startswith("__"):
+                        continue
+                    a = getattr(v, k)
+                    if inspect.isroutine(a):
+                        continue
+                    self.update(k)
+                    self.update(a)
         self.hash.update(b".")
 
     def hexdigest(self) -> str:
@@ -232,7 +196,7 @@ class Hasher:
         return self.hash.hexdigest()[:32]
 
 
-def _needs_to_implement(that: Any, func_name: str) -> None:
+def _needs_to_implement(that: Any, func_name: str) -> NoReturn:
     """Helper to raise NotImplementedError in interface stubs."""
     if hasattr(that, "_coverage_plugin_name"):
         thing = "Plugin"
@@ -243,7 +207,7 @@ def _needs_to_implement(that: Any, func_name: str) -> None:
         name = f"{klass.__module__}.{klass.__name__}"
 
     raise NotImplementedError(
-        f"{thing} {name!r} needs to implement {func_name}()"
+        f"{thing} {name!r} needs to implement {func_name}()",
     )
 
 
@@ -254,6 +218,7 @@ class DefaultValue:
     and Sphinx output.
 
     """
+
     def __init__(self, display_as: str) -> None:
         self.display_as = display_as
 
@@ -280,13 +245,13 @@ def substitute_variables(text: str, variables: Mapping[str, str]) -> str:
     dollar_pattern = r"""(?x)   # Use extended regex syntax
         \$                      # A dollar sign,
         (?:                     # then
-            (?P<dollar>\$) |        # a dollar sign, or
-            (?P<word1>\w+) |        # a plain word, or
-            {                       # a {-wrapped
-                (?P<word2>\w+)          # word,
-                (?:
-                    (?P<strict>\?) |        # with a strict marker
-                    -(?P<defval>[^}]*)      # or a default value
+            (?P<dollar> \$ ) |      # a dollar sign, or
+            (?P<word1> \w+ ) |      # a plain word, or
+            \{                      # a {-wrapped
+                (?P<word2> \w+ )        # word,
+                (?:                         # either
+                    (?P<strict> \? ) |      # with a strict marker
+                    -(?P<defval> [^}]* )    # or a default value
                 )?                      # maybe.
             }
         )
@@ -297,7 +262,7 @@ def substitute_variables(text: str, variables: Mapping[str, str]) -> str:
     def dollar_replace(match: re.Match[str]) -> str:
         """Called for each $replacement."""
         # Only one of the dollar_groups will have matched, just get its text.
-        word = next(g for g in match.group(*dollar_groups) if g)    # pragma: always breaks
+        word = next(g for g in match.group(*dollar_groups) if g)  # pragma: always breaks
         if word == "$":
             return "$"
         elif word in variables:
@@ -313,12 +278,11 @@ def substitute_variables(text: str, variables: Mapping[str, str]) -> str:
 
 
 def format_local_datetime(dt: datetime.datetime) -> str:
-    """Return a string with local timezone representing the date.
-    """
+    """Return a string with local timezone representing the date."""
     return dt.astimezone().strftime("%Y-%m-%d %H:%M %z")
 
 
-def import_local_file(modname: str, modfile: Optional[str] = None) -> ModuleType:
+def import_local_file(modname: str, modfile: str | None = None) -> ModuleType:
     """Import a local file as a module.
 
     Opens a file in the current directory named `modname`.py, imports it
@@ -338,20 +302,27 @@ def import_local_file(modname: str, modfile: Optional[str] = None) -> ModuleType
     return mod
 
 
-def _human_key(s: str) -> List[Union[str, int]]:
+@functools.cache
+def _human_key(s: str) -> tuple[list[str | int], str]:
     """Turn a string into a list of string and number chunks.
-        "z23a" -> ["z", 23, "a"]
+
+    "z23a" -> (["z", 23, "a"], "z23a")
+
+    The original string is appended as a last value to ensure the
+    key is unique enough so that "x1y" and "x001y" can be distinguished.
     """
-    def tryint(s: str) -> Union[str, int]:
+
+    def tryint(s: str) -> str | int:
         """If `s` is a number, return an int, else `s` unchanged."""
         try:
             return int(s)
         except ValueError:
             return s
 
-    return [tryint(c) for c in re.split(r"(\d+)", s)]
+    return ([tryint(c) for c in re.split(r"(\d+)", s)], s)
 
-def human_sorted(strings: Iterable[str]) -> List[str]:
+
+def human_sorted(strings: Iterable[str]) -> list[str]:
     """Sort the given iterable of strings the way that humans expect.
 
     Numeric components in the strings are sorted as numbers.
@@ -361,12 +332,14 @@ def human_sorted(strings: Iterable[str]) -> List[str]:
     """
     return sorted(strings, key=_human_key)
 
+
 SortableItem = TypeVar("SortableItem", bound=Sequence[Any])
 
+
 def human_sorted_items(
     items: Iterable[SortableItem],
     reverse: bool = False,
-) -> List[SortableItem]:
+) -> list[SortableItem]:
     """Sort (string, ...) items the way humans expect.
 
     The elements of `items` can be any tuple/list. They'll be sorted by the
