@@ -7,14 +7,22 @@ from __future__ import annotations
 
 import os
 
+REQUESTED_CORE = os.getenv("COVERAGE_CORE", "ctrace")
+
+REQUESTED_TRACER_CLASS = {
+    "ctrace": "CTracer",
+    "pytrace": "PyTracer",
+    "sysmon": "SysMonitor",
+}[REQUESTED_CORE]
+
 # Are we testing the C-implemented trace function?
-C_TRACER = os.getenv("COVERAGE_CORE", "ctrace") == "ctrace"
+C_TRACER = REQUESTED_CORE == "ctrace"
 
 # Are we testing the Python-implemented trace function?
-PY_TRACER = os.getenv("COVERAGE_CORE", "ctrace") == "pytrace"
+PY_TRACER = REQUESTED_CORE == "pytrace"
 
 # Are we testing the sys.monitoring implementation?
-SYS_MON = os.getenv("COVERAGE_CORE", "ctrace") == "sysmon"
+SYS_MON = REQUESTED_CORE == "sysmon"
 
 # Are we using a settrace function as a core?
 SETTRACE_CORE = C_TRACER or PY_TRACER
